# Changelog

## [0.0.13a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a8) (2023-10-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a7...0.0.13a8)

**Fixed bugs:**

- fix/get\_response [\#137](https://github.com/OpenVoiceOS/OVOS-workshop/pull/137) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a7) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a6...0.0.13a7)

**Fixed bugs:**

- fix/fallbackV1 [\#135](https://github.com/OpenVoiceOS/OVOS-workshop/pull/135) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a6) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a5...0.0.13a6)

**Merged pull requests:**

- fallback/no\_make\_active [\#134](https://github.com/OpenVoiceOS/OVOS-workshop/pull/134) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a5) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a4...0.0.13a5)

**Implemented enhancements:**

- refactor/get\_response\_v2\_converse\_session [\#68](https://github.com/OpenVoiceOS/OVOS-workshop/pull/68) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a4) (2023-09-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a3...0.0.13a4)

**Merged pull requests:**

- refactor/merge BaseSkill and OVOSSkill [\#133](https://github.com/OpenVoiceOS/OVOS-workshop/pull/133) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a3) (2023-09-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a2...0.0.13a3)

**Implemented enhancements:**

- feat/compat\_handler\_decorator [\#131](https://github.com/OpenVoiceOS/OVOS-workshop/pull/131) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a2) (2023-09-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a1...0.0.13a2)

**Implemented enhancements:**

- feat/sounds\_playback in ovos-audio [\#129](https://github.com/OpenVoiceOS/OVOS-workshop/pull/129) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a1) (2023-09-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.12...0.0.13a1)

**Breaking changes:**

- MessageBusClient compat [\#60](https://github.com/OpenVoiceOS/OVOS-workshop/issues/60)

**Fixed bugs:**

- fix/abstract app init [\#130](https://github.com/OpenVoiceOS/OVOS-workshop/pull/130) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
